package data
import "github.com/sigstore/sigstore-go/pkg/testing/data"
Index ¶
- func Bundle(t *testing.T, filename string) (b *bundle.Bundle)
- func TrustedRoot(t *testing.T, filename string) *root.TrustedRoot
Functions ¶
func Bundle ¶
Bundle reads a file from the embedded file system and returns a *bundle.Bundle
func TrustedRoot ¶
func TrustedRoot(t *testing.T, filename string) *root.TrustedRoot
TrustedRoot reads a file from the embedded file system and returns a *root.TrustedRoot
Source Files ¶
- Version
- v1.1.1 (latest)
- Published
- Aug 5, 2025
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 8 months ago –
Tools for package owners.